Domain models
============

Domain models framework for Python projects

Introduction
~~~~~~~~~~~~

Use cases:

- Writing some HTTP API client library, that is based on domain models pattern.

  + Examples:

    - Twitter API client library.

- Using NoSQL services with manual mapping to domain models.

  + Examples:

    - Redis.
    - Cassandra CQL.

- Using classic SQLAlchemy mapping.

  + Examples:

    - http://docs.sqlalchemy.org/en/latest/orm/mapping_styles.html#classical-mappings
